Package: mockthat
Title: Function Mocking for Unit Testing in R
Version: 0.2.8
Authors@R: 
    person(given = "Nicolas",
           family = "Bennett",
           role = c("aut", "cre"),
           email = "nicolas.bennett@stat.math.ethz.ch")
Description: With the deprecation of mocking capabilities shipped with
    'testthat' as of 'edition 3' it is left to third-party packages to replace
    this functionality, which in some test-scenarios is essential in order to
    run unit tests in limited environments (such as no Internet connection).
    Mocking in this setting means temporarily substituting a function with a
    stub that acts in some sense like the original function (for example by
    serving a HTTP response that has been cached as a file). The only exported
    function 'with_mock()' is modeled after the eponymous 'testthat' function
    with the intention of providing a drop-in replacement.
License: MIT + file LICENSE
URL: https://nbenn.github.io/mockthat/
BugReports: https://github.com/nbenn/mockthat/issues
Depends: R (>= 3.3.0)
Imports: utils, rlang
Suggests: testthat, pkgload, curl, jsonlite, withr
Encoding: UTF-8
Language: en-US
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.1
Author: Nicolas Bennett [aut, cre]
Maintainer: Nicolas Bennett <nicolas.bennett@stat.math.ethz.ch>
Built: R 4.4.0; ; 2024-05-01 11:29:05 UTC; unix
