# Generated by roxygen2: do not edit by hand

S3method(test_s3,default)
S3method(test_s3,test_cls)
export(test_base)
export(test_exported)
export(test_s3)
importFrom(curl,curl_fetch_disk)
importFrom(jsonlite,minify)
importFrom(utils,head)
